# Guía de usuario MSP430 GCC Toolchain

------

[^]: Para usuarios de Linux 

**Abstract**

This manual aims to describe the setup and basic operations of the MSP430 GCC toolchain to know how to use the open-source GCC compiler for microcontrollers to build an example for an MSP430 target device using the command terminal of Linux. It will also be shown how to debug software with the GDB Agent and the GNU Debugger tools so that the program that was built can be uploaded to the target device successfully.

------

##  Introducciòn

El paquete GCC de código abierto es un depurador completo y una cadena de herramientas de compilación C/C++ de código abierto para la creación y depuración de aplicaciones integradas basadas en microcontroladores MSP430. Este compilador soporta todos los dispositivos MSP430 sin limitaciones de tamaño de código. Este compilador se puede utilizar de forma independiente desde la línea de comandos o dentro de Code Composer Studio v6.0 o posterior[1].

El paquete de instalación incluye lo siguiente:

1. Binarios GCC y GDB para Windows y Linux
2. Encabezado MSP430 y archivos de enlace
3. Código fuente
4. GBD Agent Configuration

#### Instalación de MSP430 GCC como paquete independiente

El primer paso es bastante sencillo, consiste en abrir la terminal de comando y direccionarse a la carpeta en donde se guardará el archivo que contenga el programa a ejecutar.
Con el comando **cd** se puede entrar a alguna carpeta en específico como lo puede ser la carpeta de **Descargas**, Ejemplo:

```c
$ cd Descargas
```

Antes de continuar con el siguiente paso se debe dirigir a la pagina oficial de TI (Texas Instruments) y yendo directamente a la siguiente pagina [https://www.ti.com/tool/MSP430\-GCC\-OPENSOURCE]() en la pestaña de descargas seleccione la opción mas factible para su computadora en este caso **Mitto Systems GCC 64-bit Linux installer incl. support files**.

Una vez descargada, se debe buscar en la carpeta de descargas el nombre del archivo.
Ya una vez se tiene el nombre del archivo descargado, en la terminal de comando se debe colocar lo siguiente, lo cual nos permitirá instalar el programa, colocando sudo **chmod +x <installer>.run** y el comando **./<installer>**. 

```c
$ sudo chmod +x msp430-gcc-full-linux-X64-installer-9.3.1.2.run
$ ./msp430-gcc-full-linux-X64-installer-9.3.1.2.run
```

Lo cual abrirá la siguiente ventana:

![](/home/griscampos/Descargas/msp430Guia/1.jpeg)

Seleccione el directorio de instalacion y de click en **Next** hasta finalizar .

Como se muestra en la siguiente imagen.

![](/home/griscampos/Descargas/msp430Guia/2.jpeg)

Crea una carpeta en donde colocaras el código.

> Comando para crear carpetas desde la terminal , el comando **mkdir** + el nombre del nuevo archivo.
> Comando para encontrar carpetas dentro de la carpeta en la que se encuentra **dir**.
> Comando para entrar en carpeta **cd**.

```c
$ mkdir Programa1
$ dir 
$ cd Programa1     
```

Ya dentro de la carpeta en la que colocaras el código coloca el siguiente comando para colocar el código desde la terminal.

```c
$ main.c
```

En el cual se copiara y pegara cualquier código a utilizar.
 Ejemplo de código blink led.

```c
int main(void) {
  volatile int i;
 
  // stop watchdog timer\\
 WDTCTL = WDTPW | WDTHOLD;
  // set up bit 0 of P1 as output\\
  P1DIR = 0x01;
  // intialize bit 0 of P1 to 0\\
  P1OUT = 0x00;
 
  // loop forever\\
  for (;;) {
    // toggle bit 0 of P1\\
    %P1OUT ^= 0x01;
    // delay for a while\\
    for (i = 0; i < 0x6000; i++);
  }
}
```

#### Compilar un programa desde la termial

Una vez completados los pasos anteriores, puedes compilar tu programa desde la terminal.

```c
$ ./msp430-elf-gcc  -I ~/msp430-gcc/include -L ~/msp430-gcc/include -T ~/msp430-gcc/include/msp430fr6989.ld -mmcu=msp430fr6989 -O2 -g ~/Documentos/Code/main.c -o ~/Documentos/Code/main.o
```

Primero debes ingresar a la dirección en donde se encuentra instalado el MSP430- GCC y redireccionarte a la carpeta bin.
Para compilar se coloca ./ seguida de la dirección msp430-elf-gcc 
Y después coloca los parámetros correspondientes a -I, -L, -T, -g, -o, mmcu
Donde:
-I : Dirección donde se encuentran las librerías
-L: Dirección donde se encuentran las librerías 
-T: Dirección donde se encuentra las librerías del microcontrolador\\ especificando cual utilizaras 
-g: dirección donde se encuentra tu archivo .c
-o: dirección donde se encuentra tu archivo .c con la diferencia que se cambia el .c por .o
Mmcu: especifica el microcontrolador que utilizaras 

### Creación de un nuevo proyecto

------

##### Pasos para la creación de un nuevo proyecto

1. Crear un directorio para el nuevo proyecto.
2. Insertar el archivo .c que contiene el programa que se subirá a la tarjeta. Para crear un archivo .c vea el apartado **Creación de un archivo .c**.
3. Dentro de la carpeta que se instaló (msp430-gcc), hay un directorio llamado **examples** que contiene ejemplos predeterminados. Copiar uno de los archivos **Makefile** de los proyectos de ejemplo dentro del directorio de su nuevo proyecto.
4. Abrir el archivo **Makefile** que copió y cambiar el formato de estructura actual por el que se muestra en la Figura Estructura de archivo Makefile. En la variable **OBJECTS** se debe colocar el nombre del programa que se va a subir (archivo .c) respetando la terminación **.o**. En la variable **DEVICE** se debe colocar el nombre del microcontrolador que se usará.
5. Colocar las rutas de instalación correpondientes para las variables **GCC\_DIR** y **SUPPORT\_FILE\_DIRECTORY**. Las direcciones para las variables son **../../../bin** y **../../../include** respectivamente como se muestra en el siguiente ejemplo.

```c
OBJECTS=main.o

GCC_DIR = /home/griscampos/msp430-gcc/bin
SUPPORT_FILE_DIRECTORY = /home/griscampos/msp430-gcc/include

DEVICE  = msp430fr6989
CC      = $(GCC_DIR)/msp430-elf-gcc
GDB     = $(GCC_DIR)/msp430-elf-gdb

CFLAGS = -I $(SUPPORT_FILE_DIRECTORY) -mmcu=$(DEVICE) -O2 -g
LFLAGS = -L $(SUPPORT_FILE_DIRECTORY) -T $(DEVICE).ld

all: ${OBJECTS}
	$(CC) $(CFLAGS) $(LFLAGS) $? -o $(DEVICE).out


debug: all
	$(GDB) $(DEVICE).out
```

#### Creación de un archivo .c

Para crear un archivo .c dirijase en el directorio en el que lo desea crear y digite el siguiente comando **pico filename.c**. Por fines explicativos, como ejemplo, se creará un archivo .c llamado **Ejemplo** en la carpeta **Programa1**,como se muestra el comando antes mencionado adaptado al ejemplo.

```c
$ pico ejemplo.c
```

Para crear un archivo .c dirijase en el directorio en el que lo desea crear y digite el siguiente comando **pico filename.c**. Por fines explicativos, como ejemplo, se creará un archivo .c llamado **Ejemplo** en la carpeta **Programa1**, en la Figura se muestra el comando antes mencionado adaptado al ejemplo.

# falta imagen aquiii

### Debugging

> Uso del agente GDB 

###### Introducciòn 

El agente GDB es una herramienta para conectar el GDB con el hardware de destino para depurar su software. El GDB
El agente utiliza la pila de depuración MSP430 para conectarse al hardware y proporciona una interfaz al GDB.
En Windows, se proporciona una consola y una versión de aplicación GUI del agente GDB. Solo el
aplicación de consola es compatible con Linux.

#### Iniciando GDB Agent

###### Línea de comando

Abra una terminal de comando y dirijase al directorio de instalación, una vez que lo haga, ejecute lo siguiente:

```c
./bin/gdb\_agent\_console msp430.dat
```

La aplicación de consola abre un puerto TCP/IP en el equipo local (Figura \ref{Iniciando GDB Agent}). Muestra el número de puerto en la consola. Por defecto, este número de puerto es 55000.

[^]: Es importante que deje abierta esta consola hasta terminar de depurar el programa (debugging) para poder conectar el GDB con el GDB Agent.

```c
griscampos@griscampos-VirtualBox:~/msp430-gcc$ ./bin/gdb_agent_console msp430.dat
CPU Name             Port
--------             ----
msp430              :55000

Starting all cores
CPU Name             Status
--------             ------
msp430               Waiting for client

```

